Documentation
¶
Overview ¶
---------------------------------------------------------------------//
GNU GENERAL PUBLIC LICENSE //
Version 2, June 1991 //
//
Copyright (C) Wells Hsu, wellshsu@outlook.com, All rights reserved. // Everyone is permitted to copy and distribute verbatim copies // of this license document, but changing it is not allowed. //
SEE LICENSE.md FOR MORE DETAILS. //
---------------------------------------------------------------------//
---------------------------------------------------------------------//
GNU GENERAL PUBLIC LICENSE //
Version 2, June 1991 //
//
Copyright (C) Wells Hsu, wellshsu@outlook.com, All rights reserved. // Everyone is permitted to copy and distribute verbatim copies // of this license document, but changing it is not allowed. //
SEE LICENSE.md FOR MORE DETAILS. //
---------------------------------------------------------------------//
---------------------------------------------------------------------//
GNU GENERAL PUBLIC LICENSE //
Version 2, June 1991 //
//
Copyright (C) Wells Hsu, wellshsu@outlook.com, All rights reserved. // Everyone is permitted to copy and distribute verbatim copies // of this license document, but changing it is not allowed. //
SEE LICENSE.md FOR MORE DETAILS. //
---------------------------------------------------------------------//
---------------------------------------------------------------------//
GNU GENERAL PUBLIC LICENSE //
Version 2, June 1991 //
//
Copyright (C) Wells Hsu, wellshsu@outlook.com, All rights reserved. // Everyone is permitted to copy and distribute verbatim copies // of this license document, but changing it is not allowed. //
SEE LICENSE.md FOR MORE DETAILS. //
---------------------------------------------------------------------//
---------------------------------------------------------------------//
GNU GENERAL PUBLIC LICENSE //
Version 2, June 1991 //
//
Copyright (C) Wells Hsu, wellshsu@outlook.com, All rights reserved. // Everyone is permitted to copy and distribute verbatim copies // of this license document, but changing it is not allowed. //
SEE LICENSE.md FOR MORE DETAILS. //
---------------------------------------------------------------------//
---------------------------------------------------------------------//
GNU GENERAL PUBLIC LICENSE //
Version 2, June 1991 //
//
Copyright (C) Wells Hsu, wellshsu@outlook.com, All rights reserved. // Everyone is permitted to copy and distribute verbatim copies // of this license document, but changing it is not allowed. //
SEE LICENSE.md FOR MORE DETAILS. //
---------------------------------------------------------------------//
Index ¶
- func Append(collection interface{}, element interface{}) bool
- func AppendForAny(arr []interface{}, ele interface{}) []interface{}
- func AppendForInt(arr []int, ele int) []int
- func AppendForInt32(arr []int32, ele int32) []int32
- func AppendForInt64(arr []int64, ele int64) []int64
- func AppendForStr(arr []string, ele string) []string
- func Clear(collection interface{}) bool
- func Contains(collection interface{}, compare interface{}) bool
- func ContainsForAny(arr []interface{}, ele interface{}) bool
- func ContainsForInt(arr []int, ele int) bool
- func ContainsForInt32(arr []int32, ele int32) bool
- func ContainsForInt64(arr []int64, ele int64) bool
- func ContainsForStr(arr []string, ele string) bool
- func Delete(collection interface{}, compare interface{}) bool
- func DeleteForAny(arr []interface{}, ele int) []interface{}
- func DeleteForInt(arr []int, ele int) []int
- func DeleteForInt32(arr []int32, ele int) []int32
- func DeleteForInt64(arr []int64, ele int) []int64
- func DeleteForStr(arr []string, ele int) []string
- func Find(collection interface{}, compare interface{}) interface{}
- func Index(collection interface{}, compare interface{}) interface{}
- func IndexForAny(arr []interface{}, ele interface{}) int
- func IndexForInt(arr []int, ele int) int
- func IndexForInt32(arr []int32, ele int32) int
- func IndexForInt64(arr []int64, ele int64) int
- func IndexForStr(arr []string, ele string) int
- func Remove(collection interface{}, compare interface{}) bool
- func RemoveForAny(arr []interface{}, ele interface{}) []interface{}
- func RemoveForInt(arr []int, ele int) []int
- func RemoveForInt32(arr []int32, ele int32) []int32
- func RemoveForInt64(arr []int64, ele int64) []int64
- func RemoveForStr(arr []string, ele string) []string
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Append ¶
func Append(collection interface{}, element interface{}) bool
[Deprecated]在集合中新增元素(支持指针类型的slice),element为所要新增的元素
func AppendForAny ¶
func AppendForAny(arr []interface{}, ele interface{}) []interface{}
在数组中新增元素(interface{}),ele为元素
func Contains ¶
func Contains(collection interface{}, compare interface{}) bool
[Deprecated]判断集合是否存在元素(支持指针类型的map和slice),compare为元素或对比函数
func ContainsForAny ¶
func ContainsForAny(arr []interface{}, ele interface{}) bool
判断数组是否存在元素(interface{}),ele为元素
func Delete ¶
func Delete(collection interface{}, compare interface{}) bool
[Deprecated]从集合中移除元素(支持指针类型的map和slice),compare为索引或key值
func DeleteForAny ¶
func DeleteForAny(arr []interface{}, ele int) []interface{}
从数组中移除元素(interface{}),ele为索引
func Find ¶
func Find(collection interface{}, compare interface{}) interface{}
[Deprecated]从集合中查找元素(支持指针类型的map和slice),compare为元素或对比函数
func Index ¶
func Index(collection interface{}, compare interface{}) interface{}
[Deprecated]从集合中索引元素(支持指针类型的map和slice),compare为元素或对比函数,当集合为slice时返回number,map则返回相应key
func IndexForAny ¶
func IndexForAny(arr []interface{}, ele interface{}) int
从数组中索引元素(interface{}),ele为元素
func Remove ¶
func Remove(collection interface{}, compare interface{}) bool
[Deprecated]从集合中移除元素(支持指针类型的map和slice),compare为元素或对比函数
func RemoveForAny ¶
func RemoveForAny(arr []interface{}, ele interface{}) []interface{}
从数组中移除元素(interface{}),ele为元素
Types ¶
This section is empty.